@@ -79,154 +79,156 @@
 #'
 #' }
 cv_cluster <- function(
-    x,
-    column = NULL,
-    r = NULL,
-    k = 5L,
-    scale = TRUE,
-    raster_cluster = FALSE,
-    num_sample = 10000L,
-    biomod2 = TRUE,
-    report = TRUE,
-    ...
+        x,
+        column = NULL,
+        r = NULL,
+        k = 5L,
+        scale = TRUE,
+        raster_cluster = FALSE,
+        num_sample = 10000L,
+        biomod2 = TRUE,
+        report = TRUE,
+        ...
 ){
 
-  # check x is an sf object
-  x <- .check_x(x)
-  # is column in x?
-  column <- .check_column(column, x)
+    # check x is an sf object
+    x <- .check_x(x)
+    # is column in x?
+    column <- .check_column(column, x)
 
-  if(!is.null(r)){
-    # check for required packages
-    pkg <- c("terra")
-    .check_pkgs(pkg)
-    # check r
-    r <- .check_r(r)
-    # check r layers
-    if(terra::nlyr(r) < 1){
-      stop("'r' is not a valid raster.")
-    }
-    # scale?
-    if(scale){
-      tryCatch(
-        {
-          r <- terra::scale(r)
-        },
-        error = function(cond) {
-          message("Scaling the raster failed!")
+    if(!is.null(r)){
+        # check for required packages
+        pkg <- c("terra")
+        .check_pkgs(pkg)
+        # check r
+        r <- .check_r(r)
+        # check points fall within the raster extent
+        .check_within(x, r)
+        # check r layers
+        if(terra::nlyr(r) < 1){
+            stop("'r' is not a valid raster.")
         }
-      )
-    }
-  }
-
-
-  if(is.null(r)){
-    # spatial cluster on xy
-    xy <- sf::st_coordinates(x)
-    kms <- stats::kmeans(xy, centers = k, iter.max = 500, nstart = 25, ...)
-    x$fold <- as.integer(kms$cluster)
-
-  } else{
-    # a general check to make sure x is covered by r
-    x_vals <- terra::extract(r, x, ID = FALSE)
-    if(anyNA(x_vals)){
-      stop("The input raster layer does not cover all the column points.")
-    }
-
-    if(raster_cluster){
-      # check number of raster cells
-      if(terra::ncell(r) < 5 * num_sample){
-        rp <- length(terra::cells(r))
-        if(rp < num_sample){
-          num_sample <- rp
-          message("The num_sample reduced to ", num_sample, "; the total number of available cells.\n")
+        # scale?
+        if (scale){
+            tryCatch(
+                {
+                    r <- terra::scale(r)
+                },
+                error = function(cond) {
+                    message("Scaling the raster failed!")
+                }
+            )
         }
-      }
-      sampr <- terra::spatSample(r, size = num_sample, method = "random", na.rm = TRUE)
-      sampr <- sampr[stats::complete.cases(sampr), ]
-      sampr <- rbind(x_vals, sampr)
-      kms <- stats::kmeans(sampr, centers = k, iter.max = 500, nstart = 25, ...)
-      x$fold <- kms$cluster[seq_len(nrow(x))]
+    }
+
+
+    if (is.null(r)){
+        # spatial cluster on xy
+        xy <- sf::st_coordinates(x)
+        kms <- stats::kmeans(xy, centers = k, iter.max = 500, nstart = 25, ...)
+        x$fold <- as.integer(kms$cluster)
+
     } else{
-      kms <- stats::kmeans(x_vals, centers = k, iter.max = 500, nstart = 25, ...)
-      x$fold <- kms$cluster
+        # a general check to make sure x is covered by r
+        x_vals <- terra::extract(r, x, ID = FALSE)
+        if (anyNA(x_vals)){
+            stop("The input raster layer does not cover all the column points.")
+        }
+
+        if(raster_cluster){
+            # check number of raster cells
+            if(terra::ncell(r) < 5 * num_sample){
+                rp <- length(terra::cells(r))
+                if(rp < num_sample){
+                    num_sample <- rp
+                    message("The num_sample reduced to ", num_sample, "; the total number of available cells.\n")
+                }
+            }
+            sampr <- terra::spatSample(r, size = num_sample, method = "random", na.rm = TRUE)
+            sampr <- sampr[stats::complete.cases(sampr), ]
+            sampr <- rbind(x_vals, sampr)
+            kms <- stats::kmeans(sampr, centers = k, iter.max = 500, nstart = 25, ...)
+            x$fold <- kms$cluster[seq_len(nrow(x))]
+        } else{
+            kms <- stats::kmeans(x_vals, centers = k, iter.max = 500, nstart = 25, ...)
+            x$fold <- kms$cluster
+        }
+
     }
 
-  }
-
-  # create train-test table
-  if(is.null(column)){
-    train_test_table <- data.frame(train = rep(0, k), test = 0)
-  } else{
-    cl <- sort(unique(x[, column, drop = TRUE]))
-    clen <- length(cl)
-    .check_classes(clen, column) # column should be binary or categorical
-    train_test_table <- as.data.frame(matrix(0, nrow = k, ncol = clen * 2))
-    names(train_test_table) <- c(paste("train", cl, sep = "_"), paste("test", cl, sep = "_"))
-  }
-
-  fold_list <- list()
-  fold_ids <- rep(NA, nrow(x))
-  biomod_table <- data.frame(RUN1 = rep(TRUE, nrow(x)))
-
-  for(i in seq_len(k)){
-    test_set <- which(x$fold == i)
-    train_set <- which(x$fold != i)
-    fold_ids[test_set] <- i
-    fold_list[[i]] <- assign(paste0("fold", i), list(train_set, test_set))
+    # create train-test table
     if(is.null(column)){
-      train_test_table$train[i] <- length(train_set)
-      train_test_table$test[i] <- length(test_set)
+        train_test_table <- data.frame(train = rep(0, k), test = 0)
     } else{
-      countrain <- table(x[train_set ,column, drop = TRUE])
-      countest <- table(x[test_set ,column, drop = TRUE])
-      train_test_table[i, which(cl %in% names(countrain))] <- countrain
-      train_test_table[i, clen + which(cl %in% names(countest))] <- countest
+        cl <- sort(unique(x[, column, drop = TRUE]))
+        clen <- length(cl)
+        .check_classes(clen, column) # column should be binary or categorical
+        train_test_table <- as.data.frame(matrix(0, nrow = k, ncol = clen * 2))
+        names(train_test_table) <- c(paste("train", cl, sep = "_"), paste("test", cl, sep = "_"))
     }
-    if(biomod2){ # creating a biomod2 CV.user.table for validation
-      colm <- paste0("RUN", i)
-      biomod_table[,colm] <- FALSE
-      biomod_table[train_set, colm] <- TRUE
+
+    fold_list <- list()
+    fold_ids <- rep(NA, nrow(x))
+    biomod_table <- data.frame(RUN1 = rep(TRUE, nrow(x)))
+
+    for(i in seq_len(k)){
+        test_set <- which(x$fold == i)
+        train_set <- which(x$fold != i)
+        fold_ids[test_set] <- i
+        fold_list[[i]] <- assign(paste0("fold", i), list(train_set, test_set))
+        if(is.null(column)){
+            train_test_table$train[i] <- length(train_set)
+            train_test_table$test[i] <- length(test_set)
+        } else{
+            countrain <- table(x[train_set ,column, drop = TRUE])
+            countest <- table(x[test_set ,column, drop = TRUE])
+            train_test_table[i, which(cl %in% names(countrain))] <- countrain
+            train_test_table[i, clen + which(cl %in% names(countest))] <- countest
+        }
+        if(biomod2){ # creating a biomod2 CV.user.table for validation
+            colm <- paste0("RUN", i)
+            biomod_table[,colm] <- FALSE
+            biomod_table[train_set, colm] <- TRUE
+        }
     }
-  }
 
-  # give a warning is any folds is empty
-  zerofolds <- which(apply(train_test_table, 1, function(x) any(x < 1)))
-  if(length(zerofolds) > 0){
-    if(length(zerofolds) > 1){
-      warning("Folds ", paste(zerofolds, collapse = ", "), " have class(es) with zero records")
-    } else{
-      warning("Fold ", zerofolds, " has class(es) with zero records")
+    # give a warning is any folds is empty
+    zerofolds <- which(apply(train_test_table, 1, function(x) any(x < 1)))
+    if(length(zerofolds) > 0){
+        if(length(zerofolds) > 1){
+            warning("Folds ", paste(zerofolds, collapse = ", "), " have class(es) with zero records")
+        } else{
+            warning("Fold ", zerofolds, " has class(es) with zero records")
+        }
     }
-  }
 
-  final_objs <- list(
-    folds_list = fold_list,
-    folds_ids = fold_ids,
-    biomod_table = switch(biomod2, as.matrix(biomod_table), NULL),
-    k = k,
-    column = column,
-    type = ifelse(is.null(r), "Spatial Cluster", "Environmental Cluster"),
-    records = train_test_table
-  )
+    final_objs <- list(
+        folds_list = fold_list,
+        folds_ids = fold_ids,
+        biomod_table = switch(biomod2, as.matrix(biomod_table), NULL),
+        k = k,
+        column = column,
+        type = ifelse(is.null(r), "Spatial Cluster", "Environmental Cluster"),
+        records = train_test_table
+    )
 
-  if(report) print(train_test_table)
-  # specify the output class
-  class(final_objs) <- c("cv_cluster")
+    if(report) print(train_test_table)
+    # specify the output class
+    class(final_objs) <- c("cv_cluster")
 
-  return(final_objs)
+    return(final_objs)
 }
 
 
 #' @export
 #' @method print cv_cluster
 print.cv_cluster <- function(x, ...){
-  print(class(x))
+    print(class(x))
 }
 
 #' @export
 #' @method summary cv_cluster
 summary.cv_cluster <- function(object, ...){
-  cat("Number of recoreds in each training and testing fold:\n")
-  print(object$records)
+    cat("Number of recoreds in each training and testing fold:\n")
+    print(object$records)
 }
