@@ -29,7 +29,7 @@ test_that("test cv_spatial_autocor function works", {
   expect_equal(nrow(sac$range_table), nl)
   expect_equal(length(sac$variograms), nl)
   expect_equal(dim(sac$range_table), c(nl, 3))
-  expect_s3_class(sac$plots[[1]], "ggplot")
+  expect_true(ggplot2::is_ggplot(sac$plots[[1]]))
   expect_s3_class(sac$variograms[[1]], "autofitVariogram")
   expect_s3_class(sac$range_table, "data.frame")
   expect_type(sac$variograms, "list")
@@ -78,7 +78,7 @@ test_that("test cv_spatial_autocor function works with wgs crs", {
   expect_equal(nrow(sac$range_table), nl)
   expect_equal(length(sac$variograms), nl)
   expect_equal(dim(sac$range_table), c(nl, 3))
-  expect_s3_class(sac$plots[[1]], "ggplot")
+  expect_true(ggplot2::is_ggplot(sac$plots[[1]]))
   expect_s3_class(sac$variograms[[1]], "autofitVariogram")
   expect_s3_class(sac$range_table, "data.frame")
   expect_type(sac$variograms, "list")
